# -*- coding: utf-8 -*-
import yaml
class YamlHelper:
    yaml_data = None
    #读取yaml文件
    def __init__(self,yaml_file_path=None):
        if yaml_file_path:
            with open(yaml_file_path,mode='r',encoding='utf-8') as yaml_file_obj:
                self.yaml_data = yaml.safe_load(yaml_file_obj.read())
    def get_data_by_key(self,key=None):
        if key:
            if key in self.yaml_data:
                return self.yaml_data[key]




# -*- coding: utf-8 -*-
import pymysql,datetime
from queue import Queue
class MysqlHelper:
    def __init__(self,db_host,db_port,username,password,db_name,charset=None,maxconn = 5):
        self.maxconn = maxconn
        self.pool = Queue(maxconn)
        for i in range(maxconn):
            try:
                conn = pymysql.connect(host=db_host,port=db_port,user=username,
                                                  password=password,db=db_name)
                
                self.pool.put(conn)
            except Exception as e:
                raise IOError(e)


    def close(self):
        for i in range(self.maxconn):
            self.pool.get().close()
    def insert_many(self,sql,data=None):
        conn = self.pool.get()
        cursor = conn.cursor(cursor=pymysql.cursors.DictCursor)
        with cursor:
            try:
                cursor.executemany(sql,data)
                conn.commit()
            except Exception as e:
                conn.rollback()
        self.pool.put(conn)
    def insert(self,sql,params=None):
        conn = self.pool.get()
        cursor = conn.cursor(cursor=pymysql.cursors.DictCursor)
        with cursor:
            try:
                cursor.execute(sql,params)
                conn.commit()
            except Exception as e:
                conn.rollback()
        self.pool.put(conn)
    def update(self,sql,params=None):
        conn = self.pool.get()
        cursor = conn.cursor(cursor=pymysql.cursors.DictCursor)
        with cursor:
                try:
                    cursor.execute(sql,params)
                    conn.commit()
                except Exception as e:
                    conn.rollback()
        self.pool.put(conn)
    def query(self,sql):
        conn = self.pool.get()
        cursor = conn.cursor(cursor=pymysql.cursors.DictCursor)
        json_data = []
        with cursor:
                try:
                    count = cursor.execute(sql)
                    keys = []
                    json_data = cursor.fetchall()
                    conn.commit()
                except Exception as e:
                    print("数据库查询出错:{0},sql:{1}".format(str(e),sql))
                    conn.rollback()
        self.pool.put(conn)
        return json_data
'''
if row[q].year >= 1900:
str_time = row[q].strftime('%Y-%m-%d %H:%M:%S')
else:
str_time = '{0.year:4d}-{0.month:0>2d}-{0.day:0>2d} {0.hour:0>2d}:{0.minute:0>2d}:{0.second:0>2d}'.format(
row[q])'''


def get_url(text):
    if text == None:
        return None
    urls = re.findall(r'http[s]?://[a-zA-Z0-9\_\-]+\.[:.a-zA-Z0-9/\_\-]+', text)
    return urls

def get_user(user_list,msg):
    chat_id_temp = re.findall('@[a-zA-Z0-9\_\.\-]+', msg)
    for user in chat_id_temp:
        user_list.append(user)
def get_domain(text):
    domain_groups = re.search(
                r"(http|ftp|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?", text)
    return domain_groups
def get_facebook(user_list,msg):
    if "facebook.com/groups/" in msg:
        chat_id_temp = re.findall('facebook.com/groups/[a-zA-Z0-9\_\.\-]+', msg)
        for user in chat_id_temp:
            user_list.append(user)
    else:
        chat_id_temp = re.findall('facebook.com/[a-zA-Z0-9\_\.\-]+', msg)
        for user in chat_id_temp:
            user_list.append(user)
def get_twitter(user_list,msg):
    chat_id_temp = re.findall('twitter.com/[a-zA-Z0-9\_\.\-]+', msg)
    for user in chat_id_temp:
        user_list.append(user)
def get_tg(user_list,msg):
    if "t.me/joinchat/"  in msg:
        chat_id_temp = re.findall('t\.me/joinchat/[a-zA-Z0-9]+', msg)
        for user in chat_id_temp:
            user_list.append(user)
    else:
        chat_id_temp = re.findall('t\.me/[a-zA-Z0-9\_\.\-]+', msg)
        for user in chat_id_temp:
            user_list.append(user)


# -*- coding: utf-8 -*-
# @Time    :
# @Author  : shellvv
# @Site    :
# @File    : setup.py
# @Software: PyCharm
# @Description:

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name = "pyhelper3",
    version = "0.0.5",
    author = "shellvv",
    author_email = "shellvv@yeah.com",
    description = "",
    long_description = long_description,
    long_description_content_type="text/markdown",
    url = "http://gitee.com/shellvv/pyhelper3",
    packages = setuptools.find_packages(),
    zip_safe=False,
    install_requires=[
            'requests',
            'bs4',
            'pymysql'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]

)


# -*- coding: utf-8 -*-
import time
from datetime import datetime, date, timedelta

class TimeHelper:
    @staticmethod
    def timestamp_to_strtime(timeStamp):
        """ type timestamp str Convert to type datetime

        :param timeStamp:
        :return: type datetime
        """
        timeArray = time.localtime(timeStamp)
        return time.strftime("%Y-%m-%d %H:%M:%S", timeArray)
    @staticmethod
    def get_last_time_from_local(format,day):
        return (date.today() + timedelta(days=day)).strftime(format)

    @staticmethod
    def datetime_to_formatstring(time,format):
        if isinstance(time,datetime):
            return time.strftime(format)
    @staticmethod
    def datetime_to_ISO8801(time):
        '''
        将datetime或者timedelta对象转换成ISO 8601时间标准格式字符串
        :param time: 给定datetime或者timedelta
        :return: 根据ISO 8601时间标准格式进行输出
        '''
        if isinstance(time, datetime):  # 如果输入是datetime
            return time.isoformat();
        elif isinstance(time, timedelta):  # 如果输入时timedelta，计算其代表的时分秒
            hours = time.seconds // 3600
            minutes = time.seconds % 3600 // 60
            seconds = time.seconds % 3600 % 60
            return 'P%sDT%sH%sM%sS' % (time.days, hours, minutes, seconds)  # 将字符串进行连接




#-*- coding:utf-8 -*-
import os
from hashlib import md5
import base64
class FileHelper:
    @staticmethod
    def get_file_md5(filename):
        ret = None
        i = 0
        if not os.path.isfile(filename):
            return None,None,None
        with open(filename,'rb') as f:
            while True:
                myhash = hashlib.md5()
                b = f.read(204800)
                if not b:
                    break
                myhash.update(b)
                yield myhash.hexdigest(),b,i
                i += 1
    @staticmethod
    def get_smallfile_md5(filename):
        ret = None
        if not os.path.isfile(filename):
            return None,None,None
        myhash = hashlib.md5()
        f = open(filename,'rb')
        b = f.read()
        myhash.update(b)
        f.close()
        return myhash.hexdigest(),b,os.path.splitext(filename)[-1][1:]
    @staticmethod
    def remove_file_dir(path,flag=True):
        if path:
            if flag:
                if os.path.isdir(path):
                    os.rmdir(path)
            else:
                if os.path.exists(path):  
                    os.remove(path)
    def get_stuffix_name(file_name,is_dot=True):
        '''
        '''
        if is_dot:
            return os.path.splitext(file_name)[-1]
        else:
            return os.path.splitext(file_name)[-1][1:]


# -*- coding: utf-8 -*-
import yaml,threading,queue,time,requests
from concurrent.futures import ThreadPoolExecutor
class RequestHelper():
    __header = {
        'accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
        'accept-encoding': 'gzip, deflate, br',
        'accept-language': 'zh-CN,zh;q=0.9',
        'upgrade-insecure-requests': '1',
        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.163 Safari/537.36'}
    #构建一个队列
    def __init__(self,headers=None,proxy_host=None,proxy_port=None,timeout=10,thread_number=10,callback_func=None,**keyargs):
        self.header = RequestHelper.__header
        self.proxy = None
        self.callback_func = callback_func
        self.args = keyargs
        self.kwargs = None
        self.stop_flag = False
        self.thread_pool = ThreadPoolExecutor(thread_number)
        if headers:
            self.header = headers
        if proxy_host and proxy_port:
            self.proxy = {
                "http": "http://"+proxy_host+":"+str(proxy_port),
                "https": "https://"+proxy_host+":"+str(proxy_port)
            }
        self.timeout = timeout

    def get(url):
        ret = requests.get(url, headers=self.header, proxies=self.proxy, timeout=self.timeout)
        return ret
    def post(url):
        ret = requests.post(url, headers=self.header, proxies=self.proxy, timeout=self.timeout)
        return ret

    def run(self,url):
        try:
            response = requests.get(url, headers=self.header, proxies=self.proxy, timeout=self.timeout)
            # Website encode response.encoding
            # response.apparent_encoding
            response.encoding = response.apparent_encoding
            if self.callback_func:
                if self.args:
                    self.callback_func(self.args,response)
                else:
                    self.callback_func(response)
        except Exception as e:
            print(e)
    def put(self,url):
        self.thread_pool.submit(self.run,url)
    def stop(self):
        self.thread_pool.close()





